==> gitlab_17.0.8.orig.tar.bz2: gitlab-foss-v17.0.8/doc/administration/whats-new.md <==
---
stage: none
group: unassigned
info: For assistance with this What's new page, see https://handbook.gitlab.com/handbook/product/ux/technical-writing/#assignments-to-other-projects-and-subjects.
---

# What's new

DETAILS:
**Tier:** Free, Premium, Ultimate
**Offering:** GitLab.com, Self-managed, GitLab Dedicated

You can view some of the highlights from the last 10
GitLab versions in the **What's new** feature. It lists new features available in different
[GitLab tiers](https://about.gitlab.com/pricing/).

All users can see the feature list, but the entries might differ depending on the subscription type:

- Features only available on GitLab.com are not shown to self-managed installations.
- Features only available to self-managed installations are not shown on GitLab.com.

   NOTE:
   For self-managed installations, the updated **What's new** is included
   in the first patch release after a new version, such as `13.10.1`.

## Access What's new

To access the **What's new** feature:

1. On the left sidebar, at the bottom, select **Help** (**{question}**).
1. Select **What's new** from the menu.

## Configure What's new

You can configure **What's new** to display features based on the tier,
or you can hide it. To configure it:

1. On the left sidebar, at the bottom, select **Admin Area**.
1. Select **Settings > Preferences**.
1. Expand **What's new**, and choose one of the following options:

   | Option | Description |
   | ------ | ----------- |
   | Enable What's new: All tiers | Presents new features from all tiers. |
   | Enable What's new: Current tier only | Presents new features for your current subscription tier, and hides new features outside of your tier. |
   | Disable What's new | Disables this feature, so it no longer displays under the **{question}** icon. |

1. Select **Save changes**.

==> gitlab_17.3.5.orig.tar.bz2: gitlab-foss-v17.3.5/doc/administration/whats-new.md <==
---
stage: none
group: unassigned
info: For assistance with this What's new page, see https://handbook.gitlab.com/handbook/product/ux/technical-writing/#assignments-to-other-projects-and-subjects.
---

# What's new

DETAILS:
**Tier:** Free, Premium, Ultimate
**Offering:** GitLab.com, Self-managed, GitLab Dedicated

You can view some of the highlights from the last 10
GitLab versions in the **What's new** feature. It lists new features available in different
[GitLab tiers](https://about.gitlab.com/pricing/).

All users can see the feature list, but the entries might differ depending on the subscription type:

- Features only available on GitLab.com are not shown to self-managed installations.
- Features only available to self-managed installations are not shown on GitLab.com.

   NOTE:
   For self-managed installations, the updated **What's new** is included
   in the first patch release after a new version, such as `13.10.1`.

## Access What's new

To access the **What's new** feature:

1. On the left sidebar, at the bottom, select **Help** (**{question}**).
1. Select **What's new** from the menu.

## Configure What's new

You can configure **What's new** to display features based on the tier,
or you can hide it. To configure it:

1. On the left sidebar, at the bottom, select **Admin**.
1. Select **Settings > Preferences**.
1. Expand **What's new**, and choose one of the following options:

   | Option | Description |
   | ------ | ----------- |
   | Enable What's new: All tiers | Presents new features from all tiers. |
   | Enable What's new: Current tier only | Presents new features for your current subscription tier, and hides new features outside of your tier. |
   | Disable What's new | Disables this feature, so it no longer displays under the **{question}** icon. |

1. Select **Save changes**.
